@@ -3,7 +3,7 @@ package Getopt::optparse;
 use strict;
 use Scalar::Util 'reftype';
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
  
 $| = 1;
 
@@ -48,7 +48,7 @@ sub add_option {
     }
     else {
         print "Attributes must be passed as hashref\n";
-        return;
+        exit;
     }
 }
 
@@ -99,9 +99,11 @@ sub parse_args {
                 }
 
                 # Match for store_true and count actions.
-                if (my @matches = ($self->{cmdline} =~ /$key\s+/g)) {
-                    for my $match (@matches) {
-                        $options{$parser->{dest}} += 1;
+                if ($parser->{action} eq 'count') {
+                    if (my @matches = ($self->{cmdline} =~ /$key\s+/g)) {
+                        for my $match (@matches) {
+                            $options{$parser->{dest}} += 1;
+                        }
                     }
                 }
 
@@ -121,9 +123,30 @@ sub parse_args {
             }
         }
     }
+    for my $key (keys %{$self->{parser}}) {
+        if ($self->{parser}{$key}{action} eq 'callback') {
+            $self->run_callback(\%options);
+        }
+    }
+
     return \%options;
 }
 
+######################################################
+sub run_callback {
+######################################################
+    my $self = shift;
+    my $options = shift;
+
+    for my $key (keys %{$self->{parser}}) {
+        if ($self->{parser}{$key}{action} eq 'callback') {
+            my $parser = $self->{parser}{$key};
+                $parser->{callback}->($parser, $options);
+        }
+    }
+
+}
+
 ######################################################
 sub show_help {
 ######################################################
@@ -271,18 +294,18 @@ Add option to be parsed from command line.  Accepts two arguments.  Both are req
 
 =over 4
 
-=item Option Name
+=item Option Name (required)
 
 Value to be parsed from command line.  --hostname in the above example.  
-This library uses only double dash.
+This library supports both single and double dash option names..
 
-=item Option Attributes.  A hash reference.
+=item Option Attributes hash reference (required)
 
 These may include:
 
 =over 8
 
-=item dest
+=item dest (required)
 
 Name of key were parsed option will be stored.
 
@@ -292,7 +315,7 @@ Value of dest if no option is parsed on command line.
 
 =item help (optional)
 
-Text message displayed when --help is found on command line.
+Text message displayed when -h or --help is found on command line.
 
 =item action (optional)
 
@@ -302,15 +325,39 @@ The following actions are supported.
 
 =item store_true
 
-Using this makes dest true or false.  (0 or 1).  If the option is found.
+Using this makes dest true or false (0 or 1) if the option name is found on the command line.
 
 =item append
 
-Using this appends each occurrance of an option to an array reference.
+Using this appends each occurrance of an option to an array reference if option name is found on the command line.
 
 =item count
 
-using this increments dest by one for every occurrence.
+Using this increments dest by one for every occurrence if option name is found on the command line.
+
+=item callback
+
+Allows user to pass code reference which is executed after Getopt::optparse->parse_args() is run.  The callback has access to to all parsed options from command line.
+
+    $parser->add_option(
+        '--password', 
+        {
+            dest     => 'password',
+            help     => 'Password for account',
+            action   => 'callback',
+            callback => sub {
+                    my ($parser, $options) = @_;
+                    if ($options->{password}) {
+                        if ($options->{password} !~ /(?=[0-9])(?=[A-Z])(?=[a-z])/) {
+                            if (length($options->{password}) < 10) {
+                                print "Error: Password should be at least 10 characters, contain numbers and a lower and upper case letters.\n";
+                                exit 2;
+                            }
+                        }
+                    }
+                }
+        }
+    );
 
 =back
 
